@@ -24,9 +24,10 @@
 
 #include <glib.h>
 #include <panel-applet.h>
+#include <libgnomeui/libgnomeui.h>
 #include <string.h>
+#include <libslab/slab.h>
 
-#include "libslab-utils.h"
 #include "main-menu-ui.h"
 
 #include "main-menu-migration.h"
